wim/WimClient/inc/WimSecModule.h
branchRCL_3
changeset 5 3b17fc5c9564
parent 0 164170e6151a
--- a/wim/WimClient/inc/WimSecModule.h	Tue Feb 02 00:44:34 2010 +0200
+++ b/wim/WimClient/inc/WimSecModule.h	Fri Feb 19 23:42:03 2010 +0200
@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2002 Nokia Corporation and/or its subsidiary(-ies). 
+* Copyright (c) 2002-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 * This component and the accompanying materials are made available
 * under the terms of "Eclipse Public License v1.0"
@@ -183,10 +183,10 @@
         TInt GetWIMInfoL(); 
 
         /** 
         * Handles cleanup for an object which is not derived from CBase
         * @param aObject -object to be cleaned up
         */
-        static void Cleanup( TAny* aObject );
+        static void CleanupPinAddressList( TAny* aObject );
 
         /** 
         * Converts serialnumber to 8-bit form. Conversion reads
@@ -183,10 +183,10 @@
 
         /** 
-        * Handles cleanup for an object which is not derived from CBase
-        * @param aObject -object to be cleaned up
+        * Handles cleanup for an TPinAddress array allocated using new[].
+        * @param aObject - TPinAddress list to be cleaned up
         */